pub struct EndpointControl { /* private fields */ }Expand description
Cloneable command half returned by Endpoint::split.
Implementations
Sourceimpl EndpointControl
impl EndpointControl
Sourcepub async fn register_and_wait(
&self,
timeout: Option<Duration>,
) -> Result<EndpointRegistrationInfo>
pub async fn register_and_wait( &self, timeout: Option<Duration>, ) -> Result<EndpointRegistrationInfo>
Register and wait for a registrar success or failure event.
Sourcepub async fn registration_info(
&self,
) -> Result<Option<EndpointRegistrationInfo>>
pub async fn registration_info( &self, ) -> Result<Option<EndpointRegistrationInfo>>
Return the current registration information, if this endpoint registered.
Sourcepub async fn unregister(&self) -> Result<()>
pub async fn unregister(&self) -> Result<()>
Unregister the current account, if registered.
Sourcepub async fn unregister_and_wait(&self, timeout: Option<Duration>) -> Result<()>
pub async fn unregister_and_wait(&self, timeout: Option<Duration>) -> Result<()>
Unregister and wait for registrar confirmation.
Sourcepub async fn events(&self) -> Result<EndpointEvents>
pub async fn events(&self) -> Result<EndpointEvents>
Subscribe to Endpoint-level events.
Sourcepub fn resolve_target(&self, target: &str) -> Result<String>
pub fn resolve_target(&self, target: &str) -> Result<String>
Resolve a dial target using this endpoint’s account context.
Sourcepub fn invite(&self, target: &str) -> Result<OutboundCallBuilder>
pub fn invite(&self, target: &str) -> Result<OutboundCallBuilder>
Begin building an outbound INVITE from this endpoint’s account context. Resolves bare extensions through the configured registrar.
Sourcepub fn wrap_call(&self, call_id: CallId) -> EndpointCall
pub fn wrap_call(&self, call_id: CallId) -> EndpointCall
Materialize an EndpointCall for a CallId returned by
invite(...).send().