pub struct AuthRateLimitKey {
pub kind: AuthRateLimitKind,
pub subject: Option<String>,
pub realm: Option<String>,
pub peer: Option<String>,
}Expand description
Rate-limit key. Fields are optional so applications can key by peer, realm, subject, or any combination their deployment supports.
Fields
kind: AuthRateLimitKindOperation category.
subject: Option<String>Subject or username when known.
realm: Option<String>Realm, issuer, tenant, or provider name when known.
peer: Option<String>Source peer, IP, connection id, or SIP source when known.
Implementations
Sourceimpl AuthRateLimitKey
impl AuthRateLimitKey
Sourcepub fn new(kind: AuthRateLimitKind) -> AuthRateLimitKey
pub fn new(kind: AuthRateLimitKind) -> AuthRateLimitKey
Create a key for an auth operation.
Sourcepub fn with_subject(self, subject: impl Into<String>) -> AuthRateLimitKey
pub fn with_subject(self, subject: impl Into<String>) -> AuthRateLimitKey
Attach a subject or username.
Sourcepub fn with_realm(self, realm: impl Into<String>) -> AuthRateLimitKey
pub fn with_realm(self, realm: impl Into<String>) -> AuthRateLimitKey
Attach a realm, issuer, tenant, or provider name.
Sourcepub fn with_peer(self, peer: impl Into<String>) -> AuthRateLimitKey
pub fn with_peer(self, peer: impl Into<String>) -> AuthRateLimitKey
Attach a peer identifier.