pub enum TypedHeader {
Show 62 variants
Via(Via),
From(From),
To(To),
Contact(Contact),
CallId(CallId),
CSeq(CSeq),
Route(Route),
RecordRoute(RecordRoute),
MaxForwards(MaxForwards),
ContentType(ContentType),
ContentLength(ContentLength),
Expires(Expires),
Authorization(Authorization),
WwwAuthenticate(WwwAuthenticate),
ProxyAuthenticate(ProxyAuthenticate),
ProxyAuthorization(ProxyAuthorization),
AuthenticationInfo(AuthenticationInfo),
Accept(Accept),
Allow(Allow),
ReplyTo(ReplyTo),
ReferTo(ReferTo),
ReferredBy(ReferredBy),
Require(Require),
Warning(Vec<Warning>),
ContentDisposition(ContentDisposition),
Subject(Subject),
Event(Event),
SubscriptionState(SubscriptionState),
ContentEncoding(ContentEncoding),
ContentLanguage(ContentLanguage),
AcceptEncoding(AcceptEncoding),
AcceptLanguage(AcceptLanguage),
MinExpires(MinExpires),
MimeVersion(MimeVersion),
Supported(Supported),
Unsupported(Unsupported),
ProxyRequire(ProxyRequire),
Date(DateTime<FixedOffset>),
Timestamp((NotNan<f32>, Option<NotNan<f32>>)),
Organization(Organization),
Priority(Priority),
Server(Vec<String>),
UserAgent(Vec<String>),
InReplyTo(InReplyTo),
RetryAfter(RetryAfter),
ErrorInfo(ErrorInfoHeader),
AlertInfo(AlertInfoHeader),
CallInfo(CallInfo),
Path(Path),
ServiceRoute(ServiceRoute),
Reason(Reason),
SessionExpires(SessionExpires),
MinSE(MinSE),
RSeq(RSeq),
RAck(RAck),
SipETag(SipETag),
SipIfMatch(SipIfMatch),
AllowEvents(AllowEvents),
PAssertedIdentity(PAssertedIdentity),
PPreferredIdentity(PPreferredIdentity),
Identity(Identity),
Other(HeaderName, HeaderValue),
}Expand description
A strongly-typed representation of a SIP header.
This enum provides a type-safe way to work with parsed SIP headers. Each variant corresponds to a specific header type with its appropriately typed value.
Unlike the more generic Header, which stores headers as name-value pairs,
TypedHeader stores the header’s value in a strongly-typed form, making it safer
and more convenient to work with known header types.
Examples
use rvoip_sip_core::prelude::*;
use std::convert::TryFrom;
// Create a typed Call-ID header
let call_id = CallId::new("f81d4fae-7dec-11d0-a765-00a0c91e6bf6@example.com");
let header = TypedHeader::CallId(call_id);
// Access the header name
assert_eq!(header.name(), HeaderName::CallId);
// Convert to string representation
let header_str = header.to_string();
assert!(header_str.contains("Call-ID"));
assert!(header_str.contains("f81d4fae-7dec-11d0-a765-00a0c91e6bf6@example.com"));Variants
Via(Via)
From(From)
To(To)
Contact(Contact)
CallId(CallId)
CSeq(CSeq)
Route(Route)
RecordRoute(RecordRoute)
MaxForwards(MaxForwards)
ContentType(ContentType)
ContentLength(ContentLength)
Expires(Expires)
Authorization(Authorization)
WwwAuthenticate(WwwAuthenticate)
ProxyAuthenticate(ProxyAuthenticate)
ProxyAuthorization(ProxyAuthorization)
AuthenticationInfo(AuthenticationInfo)
Accept(Accept)
Allow(Allow)
ReplyTo(ReplyTo)
ReferTo(ReferTo)
ReferredBy(ReferredBy)
Require(Require)
Warning(Vec<Warning>)
ContentDisposition(ContentDisposition)
Subject(Subject)
Event(Event)
SubscriptionState(SubscriptionState)
ContentEncoding(ContentEncoding)
ContentLanguage(ContentLanguage)
AcceptEncoding(AcceptEncoding)
AcceptLanguage(AcceptLanguage)
MinExpires(MinExpires)
MimeVersion(MimeVersion)
Supported(Supported)
Unsupported(Unsupported)
ProxyRequire(ProxyRequire)
Date(DateTime<FixedOffset>)
Timestamp((NotNan<f32>, Option<NotNan<f32>>))
Organization(Organization)
Priority(Priority)
Server(Vec<String>)
UserAgent(Vec<String>)
InReplyTo(InReplyTo)
RetryAfter(RetryAfter)
ErrorInfo(ErrorInfoHeader)
AlertInfo(AlertInfoHeader)
CallInfo(CallInfo)
Path(Path)
ServiceRoute(ServiceRoute)
Reason(Reason)
SessionExpires(SessionExpires)
MinSE(MinSE)
RSeq(RSeq)
RAck(RAck)
RAck header (RFC 3262 7.2) — acknowledges a reliable provisional response in a PRACK request. Carries rseq, cseq, and method.
SipETag(SipETag)
SipIfMatch(SipIfMatch)
AllowEvents(AllowEvents)
PAssertedIdentity(PAssertedIdentity)
P-Asserted-Identity (RFC 3325)
PPreferredIdentity(PPreferredIdentity)
P-Preferred-Identity (RFC 3325)
Identity(Identity)
Identity (RFC 8224) — STIR signed PASSporT token
Other(HeaderName, HeaderValue)
Represents an unknown or unparsed header.
Implementations
Sourceimpl TypedHeader
impl TypedHeader
Sourcepub fn name(&self) -> HeaderName
pub fn name(&self) -> HeaderName
Returns the name of the header
Sourcepub fn as_typed_ref<'a, T>(&'a self) -> Option<&'a T>
pub fn as_typed_ref<'a, T>(&'a self) -> Option<&'a T>
Try to convert this TypedHeader to a reference of a specific header type
This method is used internally by the HeaderAccess trait implementations to provide type-safe access to headers.